@@ -26,6 +26,19 @@ def parse_args(bits, parser):
     return args, kwargs
 
 
+
+def resolve_args(args, kwargs, context):
+    new_args = []
+    new_kwargs = {}
+    for arg in args:
+        new_args.append(arg.resolve(context))
+
+    for kwarg in kwargs:
+        new_kwargs[kwarg] = kwargs[kwarg].resolve(context)
+
+    return new_args, new_kwargs
+
+
 def create_context_from_kwargs(kwargs, new_context, names, context):
     for name in names:
         if kwargs.has_key(name):
