@@ -30,8 +30,8 @@ class DIRNode(template.Node):
         return ''
 
 
-@register.tag
-def dir(parser, token):
+@register.tag('dir')
+def _dir(parser, token):
     bits = token.contents.split()
     if len(bits) < 2:
         raise template.TemplateSyntaxError("'%s' tag at least takes one arguments" % bits[0])
